function [G, Gv, Gx, Gh, Gz] = Gf( v, x, h, hAvg, z )
% G function and derivatives
% ---------------------------------------
% IN:
%   obvious
%   z   = ability parameter; usually equal to h1
% OUT:
%   G(), dG/dv, etc.
%   Derivatives are not computed if any input is 0

% TEST:
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

% *** GLOBALS ***

    global psi eta B ksi zeta gg
    dbg = 0;


% *****  INPUT CHECK  *****

    vMin = min(v);
    xMin = min(x);
    hMin = min(h);
    hAvgMin = min(hAvg);
    if dbg > 0
        minInput = min([vMin,xMin,hMin,hAvgMin]);
        if any( minInput < 0 )
            v
            x
            h
            hAvg
            abort('Negative inputs')
        end

        if isempty(z)
            abort('Gf: z empty');
        end
        if length(z) > 1
            abort('Gf: z must be scalar');
        end
    end


% *****  COMPUTATION  ******

    if all(v <= 1.05)
        G = B .* z.^gg .* h.^ksi .* v.^psi .* x.^eta .* hAvg.^zeta;
    else
        % ** Stabilize hh problem by cutting off to high inputs
        v2 = max(v, 1.05);
        G = B .* z.^gg .* h.^ksi .* v2.^psi .* x.^eta .* hAvg.^zeta;
    end

    if vMin > 1e-20
        Gv = psi .* G ./ v;
    else
        Gv = [];
    end
    if xMin > 1e-20
        Gx = eta .* G ./ x;
    else
        Gx = [];
    end
    if hMin > 1e-20
        Gh = ksi .* G ./ h;
    else
        Gh = [];
    end
    Gz = gg .* G ./ z;


% *** end function ***

