function gr = grrate(h, hx, hAvg, dbg);
% Compute growth rate per capita
% ---------------------------------------
% IN:
%   h profile of a cohort
%   hx(1) must be the initial (inherited) h
%   hAvg    average h (only used if hSpill.type == 3)

% OUT:
%   per period growth rate of per capita values

% AUTHOR: Lutz Hendricks, 1994-97
% ---------------------------------------

% *** GLOBALS ***

global hcInherit tb hcAge hSpill

if dbg > 5
   if hx(1) <= 0
      abort('GrRate: hx(1) <= 0')
   end
end

if hSpill.type == 1
   gr = (hcInherit * h(hcAge) / hx(1)) ^ (1/(tb-1));

elseif hSpill.type == 2
   % Spillover over multiple periods
   weightV = (hSpill.age2 - (hSpill.age1 : hSpill.age2)) ./ (hSpill.age2 - hSpill.age1);
   learnSum = sum( weightV .* h(hSpill.age1 : hSpill.age2) );
   gr = (hcInherit / hx(1) * learnSum) ^ (1/(tb-1));

elseif hSpill.type == 3
   % Spillover from average human capital
   abort([ mfilename, ': Not implemented' ]);
   %h1 = hcInherit * hAvg(1);
end



% *** end function ***
