function dev = hhdevjmr(r,w,hAvg, a,h, c,u,v,x, a1,h1,c1,l1, Tr,tc,cx)
% Deviations from hh foc's and b.c. of JMR's model
% ---------------------------------------
% TASK:
%   Compute deviations from hh foc's and b.c. of JMR's model 2, modified to allow for
%   hc spillovers.
%   Assumes bgp
%   Function held very general. Very little dependency on functional forms.
% IN:
%   r       net interest rate
%   w       net wage rate per unit of effective labor
%   hAvg    average h
%   a       assets
%   h       h
%   c, u, v standard notation
%   x       goods inputs to G()
%   c1, a1, h1      ditto at t+1
%   Tr              lump-sum transfer
%   tc              consumption tax rate
%   cx              private cost of x
% OUT:
%   deviations 1x5


% ERRORS:
%
% TEST:
%
% AUTHOR: Lutz Hendricks, 1994
% ---------------------------------------

% *** CONSTANTS ***

    global bb ddh

    % Ability effects in G() not used
    z = 1;

% ************  FUNCTIONAL FORMS  ************************

    l = 1 - u - v;
    [ util, uc, ul ] = ufct( c, l );

    [ util, uc1, ul1 ] = ufct( c1, l1 );
    
    [G, Gv, Gx, Gh, Gz] = gf( v, x, h, hAvg, z );


% ************  DEVIATIONS  *******************************

    dev = zeros(1,5);
    
    dev(1) = bb * (1+r) * uc1 / uc  - 1;

    dev(2) = uc / ul * w * h / (1+tc) - 1;

    dev(3) = Gv / Gx * cx / w / h - 1;

    % Based on Gv/h constant over time. Equ (4)    
    dev(4) = h / Gv * (1-ddh + Gh - 1-r) / u + 1;
    
    % B.C.
    revenue = Tr + w*h*u + (1+r)*a;
    expend  = c*(1+tc) + x*cx + a1;
    dev(5) = expend / revenue - 1;

% *** end function ***
