function parachk
% parachk: Check that calibrated parameters are consistent
% ---------------------------------------

% AUTHOR: Lutz Hendricks, 1993-97
% ---------------------------------------

% *** GLOBALS ***

global ksix gg etax psix Bx ddhx Tx h1Invest hAbility
global bb sig theta rho nu popGrowth tb
global A aa
global B psi eta ksi zeta ddh ddk
global yearsOfLife iniAge hcInherit T1
global sigMin
global bequ BEQUTYPE NOBEQUEST ALTRUISTIC NONALTRUISTIC hcAltruism hSpill
global grTarget IYTarget vTarget hTarget calRho


   % Was there a fatal error?
   fatal = 0;

   TOLERANCE = 1e-6;

   disp(' ')
   disp('Checking parameters...')

    if sig < sigMin
        sig
        sigMin
        warnmsg('sig < sigMin')
    end

    if (1-psi-eta) < 0.15
        psi
        eta
        warnmsg('1-psi-eta < 0.15')
    end

    if hAbility == 0
       if abs(zeta+eta+ksi - 1) > TOLERANCE
           warnmsg('zeta+eta+ksi ~= 1')
       end
    else
       if abs(gg+eta+ksi - 1) > TOLERANCE
           warnmsg('gg+eta+ksi ~= 1')
       end
    end

    if ~isint(tb)
       tb
       warnmsg('tb not integer')
       fatal = 1;
    end


% ***************** h1 Investment  **********************

if h1Invest == 1
   v_check( Tx, 'f', [1,1], 1, 99 );
   v_check( psix, 'f', [1,1], 1e-5, 1 );
   v_check( etax, 'f', [1,1], 1e-5, 1 );
   % Returns to scale in h1 investment
   % include psix because v is effective labor here
   if hAbility == 1
      if  psix + etax + gg > 1
         warnmsg('psix + etax + gg > 1');
      end
   end
end



% *****************  BEQUESTS  **********************
if bequ > 0
   if hcAltruism == 1
      if bequ <= 0  |  BEQUTYPE == NOBEQUEST
         warnmsg('hcAltruism requires bequests');
      end

      v_check( hSpill.type, 'i', [1,1], 1, 3 );
      v_check( hSpill.age1, 'i', [1,1], 1, hSpill.age2 );
      v_check( hSpill.age2, 'i', [1,1], hSpill.age1, tb );
      if hSpill.type == 3
         % Cannot have internalization if average h spillover
         if hcAltruism ~= 0
            abort([ mfilename, ': hcAltruism with hSpill.type = 3' ]);
         end
      end
   end
end


if fatal > 0
   abort([ mfilename, ': Invalid calibration.' ]);
end


% **************  CALIBRATION TARGETS  **************
if calRho.lTarget < 0.4  |  calRho.lTarget > 0.8
   disp(lTarget)
   warnmsg('Implausible leisure share target.');
end

if IYTarget < 0.1  |  IYTarget > 0.4
   disp(IYTarget)
   warnmsg('Implausible investment share target.');
end

if grTarget <= 1  |  grTarget > 2
   warnmsg(sprintf('Implausible growth target: %f', grTarget));
end

v_check( hTarget.age2, 'f', [1,1], 2, T1 );
v_check( hTarget.age1, 'f', [1,1], 1, hTarget.age2-1 );



% *** end function ***

