function x = pdtoyr(xpd, yPerPd)
% Compute annual values from period-by-period values
% ---------------------------------------
% IN:
%   xpd = values of x for periods 1...N
%   yPerPd  = years per period
% OUT:
%   x   = values of x for years 1...Ymax
% REM:
% - a linear interpolation is used between periods.

% TEST:
%   t_pdtoyr
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

    N = length(xpd);
    Ymax = (N-1) * yPerPd;
    x(1) = xpd(1);
    
    
    for yr = 2 : Ymax;
        % year corresponding to yr; fractional
        pd2 = (yr-1) / yPerPd + 1;
        % last full year corresponding to yr
        pd1 = floor(pd2);
        x(yr) = xpd(pd1) + (pd2-pd1) * (xpd(pd1+1) - xpd(pd1));
    end
    
    
% *** end function ***

