function r = rnet(k, tk, kDeduct, ddk)
% Compute after tax interest rate from K/L
% ---------------------------------------
% IN:
%  may be row or column vectors
%  k        capital/labor ratio
%  tk       factor tax rates
%  kDeduct  fraction of depreciation which is tax deductible
% OUT:
%  r        after tax and depreciation factor prices; dimensions as K and L


% ERRORS:
% - negative r
% TEST:
%
% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------


% ******  INPUT CHECKING  *******
  if 1
    if  isempty(k)  |  isempty(tk)
        disp('--- Invalid inputs ---------------------')
        k
        tk
        abort('---------------------')
    end
  end
  
  
% ******  COMPUTATION  *********
    [tmp, MPK] = prodfct(k, 1);
    r = (1-tk) .* MPK - (1-kDeduct.*tk) .* ddk;


    if 1
        if  any(r < 0)
            matprint( [k', MPK', r'], 0, ...
            '       -k-     -MPK-       -r-' )
            warnmsg('rNet: Negative r')
        end
        if  any(r <= -1)
            abort('Aborted by rnet')
        end
    end

% *** end function ***
