function rev = taxrev(MPK,K,tk,ddk,kDeduct, tc,C, MPL,L,X,tw, Lold,Xold,...
    to,xDeduct,xEarn,sx, BTaggr,taxb,Xx,sxx)
% Tax revenue; subtracting education subsidies!
% ---------------------------------------
% IN:
%   capital letters denote aggregates
%   Lold,Xold = aggregate L and X of retired agents subject to old-age tax
%   to  = old age tax rate
%   BTaggr  = aggregate bequests at date
%   Xx      = aggregate goods inputs in h1 investment
%   sxx     = subsidy rate on Xx
% OUT:
%   tax revenue; excluding payroll taxes but including old age wage taxes

% AUTHOR: Lutz Hendricks, 1993
% ---------------------------------------

    dbg = 0;

% ***  ***

    krev = ktax(MPK, K, tk, ddk, kDeduct);
    crev = tc .* C;
    lrev = ltax(MPL, L, X, tw, xDeduct,xEarn) + ...
           ltax(MPL, Lold, Xold, to, xDeduct,xEarn);
    brev = BTaggr .* taxb;
    xrev = - Xx.*sxx - sx.*(1-xEarn).*X;
    rev = krev + crev + lrev + brev + xrev;


% ********  SHOW REVENUE SHARES  *********

    if dbg > 5
        Ynet  = prodfct(K, L) - ddk.*K;
        disp('TaxRev: Tax revenue shares in Ynet:');
        tmp = sprintf('tk: %6.3f   tl: %6.3f    tc: %6.3f', ...
            krev./Ynet, lrev./Ynet, crev./Ynet);
        disp(tmp);
        tmp = sprintf('tb: %6.3f   sx: %6.3f   sum: %6.3f', ...
            brev./Ynet, xrev./Ynet, rev./Ynet);
        disp(tmp);
    end

% *** end function ***

